@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.cpp 1439 2007-01-20 22:46:40Z jframeau $
+ *  $Id: mozilla-helpers.cpp 1544 2007-07-15 10:21:24Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -428,7 +428,7 @@ PageInfoHelper::GetProperties ()
 
   nsTime last_modified (cTmp.get(), PR_TRUE);
   LL_DIV (props->modification_time,
-          NS_STATIC_CAST(PRTime, last_modified), PR_USEC_PER_SEC);
+          static_cast<PRTime>(last_modified), PR_USEC_PER_SEC);
 
   rv = domNSDoc->GetContentType (value);
   NS_ENSURE_SUCCESS (rv, props);
